==> breeze_update_3.6.05.tar.gz: manage/assign_menu.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 10/12/2009
// Revined: 1/8/2011	ELL
// Added calls for adding and removing JavaScript menu code.
// Revised: 2/7/2012	ELL
// Added table prefix handling.
//
	
	include ("check_session.php");
	
	$border_area = $_REQUEST['border_area'];
	$menu_name = $_REQUEST['menu_name'];
	$menu_type = $_REQUEST['menu_type'];
	
	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "menu_assignments` WHERE border_area = '$border_area'";
	$result = mysql_query($query, $bwb_link);
	if (mysql_num_rows($result) == 0)
	{
		if ($menu_name != "-not assigned-")
		{
			$query2 = "INSERT INTO `" . BWB_TABLE_PREFIX . "menu_assignments` SET menu_name = '$menu_name', border_area = '$border_area'";
			$result2 = mysql_query($query2, $bwb_link);
		}
	}
	else
	{
		if ($menu_name != "-not assigned-")
			$query2 = "UPDATE `" . BWB_TABLE_PREFIX . "menu_assignments` SET menu_name = '$menu_name', border_area = '$border_area'";
		else
			$query2 = "DELETE FROM `" . BWB_TABLE_PREFIX . "menu_assignments` WHERE border_area = '$border_area'";
		$result2 = mysql_query($query2, $bwb_link);
	}
	///////////////////////////////////////////////////////////////////////////////////
	if ($menu_type == 1)
	{
		if ($menu_name != "-not assigned-")
		{
			$suffix = substr($menu_name, 4);
			include("add_menu_code.php");
		}
		else
			include("remove_menu_code.php");
	}
	///////////////////////////////////////////////////////////////////////////////////
	
	header("Location: manage_menu.php");
?>

==> breeze_update_4.0.01.tar.gz: manage/assign_menu.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 10/12/2009
// Revined: 1/8/2011	ELL
// Added calls for adding and removing JavaScript menu code.
// Revised: 2/7/2012	ELL
// Added table prefix handling.
//
	
	include ("check_session.php");
	
	$border_area = $_REQUEST['border_area'];
	$menu_name = $_REQUEST['menu_name'];
	$menu_type = $_REQUEST['menu_type'];
	
	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "menu_assignments` WHERE border_area = '$border_area'";
	$result = $bwb_dbh->query($query);
	if ($result->rowCount() == 0)
	{
		if ($menu_name != "-not assigned-")
		{
			$query2 = "INSERT INTO `" . BWB_TABLE_PREFIX . "menu_assignments` SET menu_name = '$menu_name', border_area = '$border_area'";
			$cnt = $bwb_dbh->exec($query2);
		}
	}
	else
	{
		if ($menu_name != "-not assigned-")
			$query2 = "UPDATE `" . BWB_TABLE_PREFIX . "menu_assignments` SET menu_name = '$menu_name', border_area = '$border_area'";
		else
			$query2 = "DELETE FROM `" . BWB_TABLE_PREFIX . "menu_assignments` WHERE border_area = '$border_area'";
		$cnt = $bwb_dbh->exec($query2);
	}
	///////////////////////////////////////////////////////////////////////////////////
	if ($menu_type == 1)
	{
		if ($menu_name != "-not assigned-")
		{
			$suffix = substr($menu_name, 4);
			include("add_menu_code.php");
		}
		else
			include("remove_menu_code.php");
	}
	///////////////////////////////////////////////////////////////////////////////////
	
	header("Location: manage_menu.php");
?>
